@@ -134,7 +134,7 @@ class figure:
     self.__yticklabel._set_tick_labels(labels)
 
   def set_legend_position(self, pos: str):
-    self.__legend.pos.set_value(pos)
+    self.__legend._set_position(pos)
 
   def set_plottype(self, type: str = 'xy', idx: int = -1):
     self.__curves[idx]._set_plottype(type)
